Crate lance_namespace

Crate lance_namespace 

Lance Namespace Rust Client

A Rust client for the Lance Namespace API that provides a unified interface for managing namespaces and tables across different backend implementations.

Error Handling

This crate provides fine-grained error types through the error module. Each error type has a unique numeric code that is consistent across all Lance Namespace implementations (Python, Java, Rust, REST).

See error::ErrorCode for the list of error codes and error::NamespaceError for the error types.

Re-exports

pub use namespace::LanceNamespace;
pub use error::ErrorCode;
pub use error::NamespaceError;
pub use error::Result as NamespaceResult;
pub use lance_namespace_reqwest_client as reqwest_client;

Modules

apis
compat
Deserialization shims that keep older SDK builds working against current native code.
error
Lance Namespace error types.
models
namespace
Lance Namespace base interface and implementations.
schema
Schema conversion utilities for Lance Namespace.

Enums

Error

Type Aliases

Result