pub async fn count_table_rows(
configuration: &Configuration,
id: &str,
count_table_rows_request: CountTableRowsRequest,
delimiter: Option<&str>,
) -> Result<i64, Error<CountTableRowsError>>Expand description
Count the number of rows in table id REST NAMESPACE ONLY REST namespace returns the response as a plain integer instead of the CountTableRowsResponse JSON object. The REST response maps to the CountTableRowsResponse model as follows: - the integer response body maps to count - response headers map to context via the header. prefix (see the Context schema)