insert_into_table

Function insert_into_table 

pub async fn insert_into_table(
    configuration: &Configuration,
    id: &str,
    body: Vec<u8>,
    delimiter: Option<&str>,
    mode: Option<&str>,
) -> Result<InsertIntoTableResponse, Error<InsertIntoTableError>>
Insert new records into table id. For tables that have been declared but not yet created on storage (is_only_declared=true), this operation will create the table with the provided data. REST NAMESPACE ONLY REST namespace uses Arrow IPC stream as the request body. It passes in the InsertIntoTableRequest information in the following way: - id: pass through path parameter of the same name - mode: pass through query parameter of the same name