create_table

Function create_table 

pub async fn create_table(
    configuration: &Configuration,
    id: &str,
    body: Vec<u8>,
    delimiter: Option<&str>,
    mode: Option<&str>,
    properties: Option<&str>,
    storage_options: Option<&str>,
) -> Result<CreateTableResponse, Error<CreateTableError>>
Create table id in the namespace with the given data in Arrow IPC stream. The schema of the Arrow IPC stream is used as the table schema. If the stream is empty, the API creates a new empty table. REST NAMESPACE ONLY REST namespace uses Arrow IPC stream as the request body. It passes in the CreateTableRequest information in the following way: - id: pass through path parameter of the same name - mode: pass through query parameter of the same name - properties: serialize as a single JSON-encoded query parameter such as properties={\"user\":\"alice\",\"team\":\"eng\"}; these are business logic properties managed by the namespace implementation outside Lance context - storage_options: serialize as a single JSON-encoded query parameter such as storage_options={\"aws_region\":\"us-east-1\",\"timeout\":\"30s\"}; these configure write-time overrides for data and metadata written during table creation