update_table_schema_metadata

Function update_table_schema_metadata 

pub async fn update_table_schema_metadata(
    configuration: &Configuration,
    id: &str,
    request_body: HashMap<String, String>,
    delimiter: Option<&str>,
    branch: Option<&str>,
) -> Result<HashMap<String, String>, Error<UpdateTableSchemaMetadataError>>
Replace the schema metadata for table id with the provided key-value pairs. REST NAMESPACE ONLY REST namespace uses a direct object (map of string to string) as both request and response body instead of the wrapped UpdateTableSchemaMetadataRequest and UpdateTableSchemaMetadataResponse.