Error

Enum Error 

pub enum Error {
Show 33 variants InvalidInput { source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, DatasetAlreadyExists { uri: String, location: &'static Location<'static>, }, SchemaMismatch { difference: String, location: &'static Location<'static>, }, DatasetNotFound { path: String, source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, CorruptFile { path: Path, source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, NotSupported { source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, CommitConflict { version: u64, source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, IncompatibleTransaction { source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, RetryableCommitConflict { version: u64, source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, TooMuchWriteContention { message: String, location: &'static Location<'static>, }, Internal { message: String, location: &'static Location<'static>, }, PrerequisiteFailed { message: String, location: &'static Location<'static>, }, Unprocessable { message: String, location: &'static Location<'static>, }, Arrow { message: String, location: &'static Location<'static>, }, Schema { message: String, location: &'static Location<'static>, }, NotFound { uri: String, location: &'static Location<'static>, }, IO { source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, Index { message: String, location: &'static Location<'static>, }, IndexNotFound { identity: String, location: &'static Location<'static>, }, InvalidTableLocation { message: String, }, Stop, Wrapped { error: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, Cloned { message: String, location: &'static Location<'static>, }, Execution { message: String, location: &'static Location<'static>, }, InvalidRef { message: String, }, RefConflict { message: String, }, RefNotFound { message: String, }, Cleanup { message: String, }, VersionNotFound { message: String, }, VersionConflict { message: String, major_version: u16, minor_version: u16, location: &'static Location<'static>, }, Namespace { source: Box<dyn Error + Sync + Send>, location: &'static Location<'static>, }, External { source: Box<dyn Error + Sync + Send>, }, FieldNotFound { source: FieldNotFoundError, },
}

Variants



InvalidInput

Fields

source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


DatasetAlreadyExists

Fields

location: &'static Location<'static>


SchemaMismatch

Fields

difference: String
location: &'static Location<'static>


DatasetNotFound

Fields

path: String
source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


CorruptFile

Fields

path: Path
source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


NotSupported

Fields

source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


CommitConflict

Fields

version: u64
source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


IncompatibleTransaction

Fields

source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


RetryableCommitConflict

Fields

version: u64
source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


TooMuchWriteContention

Fields

message: String
location: &'static Location<'static>


Internal

Fields

message: String
location: &'static Location<'static>


PrerequisiteFailed

Fields

message: String
location: &'static Location<'static>


Unprocessable

Fields

message: String
location: &'static Location<'static>


Arrow

Fields

message: String
location: &'static Location<'static>


Schema

Fields

message: String
location: &'static Location<'static>


NotFound

Fields

location: &'static Location<'static>


IO

Fields

source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


Index

Fields

message: String
location: &'static Location<'static>


IndexNotFound

Fields

identity: String
location: &'static Location<'static>


InvalidTableLocation

Fields

message: String


Stop

Stream early stop



Wrapped

Fields

error: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


Cloned

Fields

message: String
location: &'static Location<'static>


Execution

Fields

message: String
location: &'static Location<'static>


InvalidRef

Fields

message: String


RefConflict

Fields

message: String


RefNotFound

Fields

message: String


Cleanup

Fields

message: String


VersionNotFound

Fields

message: String


VersionConflict

Fields

message: String
major_version: u16
minor_version: u16
location: &'static Location<'static>


Namespace

Fields

source: Box<dyn Error + Sync + Send>
location: &'static Location<'static>


External

External error passed through from user code.

This variant preserves errors that users pass into Lance APIs (e.g., via streams with custom error types). The original error can be recovered using Error::into_external or inspected using Error::external_source.

Fields

source: Box<dyn Error + Sync + Send>


FieldNotFound

A requested field was not found in a schema.

Fields

Implementations

Source

impl Error

pub fn corrupt_file(path: Path, message: impl Into<String>) -> Error

pub fn invalid_input(message: impl Into<String>) -> Error

pub fn invalid_input_source(source: Box<dyn Error + Sync + Send>) -> Error

pub fn io(message: impl Into<String>) -> Error

pub fn io_source(source: Box<dyn Error + Sync + Send>) -> Error

pub fn dataset_already_exists(uri: impl Into<String>) -> Error

pub fn dataset_not_found( path: impl Into<String>, source: Box<dyn Error + Sync + Send>, ) -> Error

pub fn version_conflict( message: impl Into<String>, major_version: u16, minor_version: u16, ) -> Error

pub fn not_found(uri: impl Into<String>) -> Error

pub fn wrapped(error: Box<dyn Error + Sync + Send>) -> Error

pub fn schema(message: impl Into<String>) -> Error

pub fn not_supported(message: impl Into<String>) -> Error

pub fn not_supported_source(source: Box<dyn Error + Sync + Send>) -> Error

pub fn internal(message: impl Into<String>) -> Error

pub fn namespace(message: impl Into<String>) -> Error

pub fn namespace_source(source: Box<dyn Error + Sync + Send>) -> Error

pub fn arrow(message: impl Into<String>) -> Error

pub fn execution(message: impl Into<String>) -> Error

pub fn cloned(message: impl Into<String>) -> Error

pub fn schema_mismatch(difference: impl Into<String>) -> Error

pub fn unprocessable(message: impl Into<String>) -> Error

pub fn too_much_write_contention(message: impl Into<String>) -> Error

pub fn prerequisite_failed(message: impl Into<String>) -> Error

pub fn index(message: impl Into<String>) -> Error

pub fn index_not_found(identity: impl Into<String>) -> Error

pub fn commit_conflict_source( version: u64, source: Box<dyn Error + Sync + Send>, ) -> Error

pub fn retryable_commit_conflict_source( version: u64, source: Box<dyn Error + Sync + Send>, ) -> Error

pub fn incompatible_transaction_source( source: Box<dyn Error + Sync + Send>, ) -> Error

pub fn external(source: Box<dyn Error + Sync + Send>) -> Error

Create an External error from a boxed error source.

pub fn field_not_found( field_name: impl Into<String>, candidates: Vec<String>, ) -> Error

Create a FieldNotFound error with the given field name and available candidates.

pub fn external_source(&self) -> Option<&Box<dyn Error + Sync + Send>>

Returns a reference to the external error source if this is an External variant.

This allows downcasting to recover the original error type.

pub fn into_external(self) -> Result<Box<dyn Error + Sync + Send>, Error>

Consumes the error and returns the external source if this is an External variant.

Returns Err(self) if this is not an External variant, allowing for chained handling.