AlterTransactionAction : A single action that could be performed to alter a transaction. This action holds the model definition for all types of specific actions models, this is to minimize difference and compatibility issue across codegen in different languages. When used, only one of the actions should be non-null for each action. If you would like to perform multiple actions, set a list of actions in the AlterTransactionRequest.
AlterTransactionRequest : Alter a transaction with a list of actions. The server should either succeed and apply all actions, or fail and apply no action.
BatchCommitTablesRequest : Request to atomically commit a batch of table operations. This replaces BatchCreateTableVersionsRequest with a more general interface that supports mixed operations (DeclareTable, CreateTableVersion, DeleteTableVersions, DeregisterTable) within a single atomic transaction at the metadata layer. All operations are committed atomically: either all succeed or none are applied.
BatchCreateTableVersionsRequest : Request to atomically create new version entries for multiple tables. The operation is atomic: all versions are created or none are.
BatchCreateTableVersionsResponse : Response for batch creating table versions. Contains the created versions for each table in the same order as the request.
CommitTableResult : Result of a single operation within a batch commit. Each result corresponds to one operation in the request, in the same order. Exactly one of the result fields will be set.
CountTableRowsResponse : Response containing the count of rows. The REST namespace does not transmit this object directly (see the CountTableRows operation for how the bare-number response maps to it). It is the standard data model for the LanceNamespace interfaces (e.g. Java, Python).
CreateTableRequest : Request for creating a table, excluding the Arrow IPC stream. The table location and any credential vending behavior are determined by the implementation and returned in the response, rather than specified in this request.
CreateTableVersionEntry : An entry for creating a new table version in a batch operation. This supports put_if_not_exists semantics, where the operation fails if the version already exists.
CreateTableVersionRequest : Request to create a new table version entry. This supports put_if_not_exists semantics, where the operation fails if the version already exists.
DropTableRequest : If the table and its data can be immediately deleted, return information of the deleted table. Otherwise, return a transaction ID that client can use to track deletion progress.
FtsQuery : Full-text search query. Exactly one query type field must be provided. This structure follows the same pattern as AlterTransactionAction to minimize differences and compatibility issues across codegen in different languages.
NamespaceExistsResponse : Response for a namespace existence check. The REST namespace does not transmit this object directly (see the NamespaceExists operation for how the status-code response maps to it). It is the standard data model for the LanceNamespace interfaces (e.g. Java, Python).
QueryTableResponse : Query results. The REST namespace does not transmit this object directly (see the QueryTable operation for how the Arrow IPC binary response maps to it). It is the standard data model for the LanceNamespace interfaces (e.g. Java, Python).
TableExistsResponse : Response for a table existence check. The REST namespace does not transmit this object directly (see the TableExists operation for how the status-code response maps to it). It is the standard data model for the LanceNamespace interfaces (e.g. Java, Python).
UpdateTableRequest : Each update consists of a field path and an SQL expression that will be evaluated against the current row’s value. Optionally, a predicate can be provided to filter which rows to update.
VersionRange : A range of versions to delete (start inclusive, end exclusive). Special values: - start_version: 0 with end_version: -1 means ALL versions