Module batch_commit_tables_request

Module batch_commit_tables_request 

Structs

BatchCommitTablesRequest
BatchCommitTablesRequest : Request to atomically commit a batch of table operations. This replaces BatchCreateTableVersionsRequest with a more general interface that supports mixed operations (DeclareTable, CreateTableVersion, DeleteTableVersions, DeregisterTable) within a single atomic transaction at the metadata layer. All operations are committed atomically: either all succeed or none are applied.