pub struct BatchCommitTablesResponse {
pub transaction_id: Option<String>,
pub results: Vec<CommitTableResult>,
}Expand description
BatchCommitTablesResponse : Response for a batch commit of table operations. Contains the results of each operation in the same order as the request.
Fields
transaction_id: Option<String>Optional transaction identifier for the batch commit
results: Vec<CommitTableResult>Results for each operation, in the same order as the request operations. Each result contains the outcome of the corresponding operation.
Implementations
Sourceimpl BatchCommitTablesResponse
impl BatchCommitTablesResponse
Sourcepub fn new(results: Vec<CommitTableResult>) -> BatchCommitTablesResponse
pub fn new(results: Vec<CommitTableResult>) -> BatchCommitTablesResponse
Response for a batch commit of table operations. Contains the results of each operation in the same order as the request.