pub struct BatchCreateTableVersionsResponse {
pub context: Option<HashMap<String, String>>,
pub transaction_id: Option<String>,
pub versions: Vec<TableVersion>,
}Expand description
BatchCreateTableVersionsResponse : Response for batch creating table versions. Contains the created versions for each table in the same order as the request.
Fields
context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
transaction_id: Option<String>Optional transaction identifier
versions: Vec<TableVersion>List of created table versions in the same order as the request entries
Implementations
Sourceimpl BatchCreateTableVersionsResponse
impl BatchCreateTableVersionsResponse
Sourcepub fn new(versions: Vec<TableVersion>) -> BatchCreateTableVersionsResponse
pub fn new(versions: Vec<TableVersion>) -> BatchCreateTableVersionsResponse
Response for batch creating table versions. Contains the created versions for each table in the same order as the request.