pub struct BatchDeleteTableVersionsRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub branch: Option<String>,
pub ranges: Vec<VersionRange>,
}Expand description
BatchDeleteTableVersionsRequest : Request to delete table version records. Supports deleting ranges of versions for efficient bulk cleanup.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>The table identifier
branch: Option<String>Branch to target. When not specified, the main branch is used.
ranges: Vec<VersionRange>List of version ranges to delete. Each range specifies start (inclusive) and end (exclusive) versions.
Implementations
Sourceimpl BatchDeleteTableVersionsRequest
impl BatchDeleteTableVersionsRequest
Sourcepub fn new(ranges: Vec<VersionRange>) -> BatchDeleteTableVersionsRequest
pub fn new(ranges: Vec<VersionRange>) -> BatchDeleteTableVersionsRequest
Request to delete table version records. Supports deleting ranges of versions for efficient bulk cleanup.