pub struct CommitTableOperation {
pub declare_table: Option<Box<DeclareTableRequest>>,
pub create_table_version: Option<Box<CreateTableVersionRequest>>,
pub delete_table_versions: Option<Box<BatchDeleteTableVersionsRequest>>,
pub deregister_table: Option<Box<DeregisterTableRequest>>,
}Expand description
CommitTableOperation : A single operation within a batch commit. Provide exactly one of the operation fields to specify the operation kind.
Fields
declare_table: Option<Box<DeclareTableRequest>>Declare (reserve) a new table in the namespace
create_table_version: Option<Box<CreateTableVersionRequest>>Create a new version entry for a table
delete_table_versions: Option<Box<BatchDeleteTableVersionsRequest>>Delete version ranges from a table
deregister_table: Option<Box<DeregisterTableRequest>>Deregister (soft-delete) a table
Implementations
Sourceimpl CommitTableOperation
impl CommitTableOperation
Sourcepub fn new() -> CommitTableOperation
pub fn new() -> CommitTableOperation
A single operation within a batch commit. Provide exactly one of the operation fields to specify the operation kind.