Module commit_table_result

Module commit_table_result 

Structs

CommitTableResult
CommitTableResult : Result of a single operation within a batch commit. Each result corresponds to one operation in the request, in the same order. Exactly one of the result fields will be set.