pub struct CountTableRowsRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub version: Option<i64>,
pub branch: Option<String>,
pub predicate: Option<String>,
}Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>version: Option<i64>Version of the table to describe. If not specified, server should resolve it to the latest version.
branch: Option<String>Branch to target. When not specified, the main branch is used.
predicate: Option<String>Optional SQL predicate to filter rows for counting. Field references must use Lance field path syntax: nested fields use dot-separated segments, literal dots require backtick-quoted segments, and backticks inside quoted segments are doubled.
Implementations
Sourceimpl CountTableRowsRequest
impl CountTableRowsRequest
pub fn new() -> CountTableRowsRequest