pub struct CreateTableBranchRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub name: String,
pub from_branch: Option<String>,
pub from_version: Option<i64>,
}Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
id: Option<Vec<String>>name: StringName of the branch to create
from_branch: Option<String>Source branch to create the new branch from. When omitted, the new branch is created from the main branch.
from_version: Option<i64>Version of the source (branch or main) to create from. When omitted, the latest version of the source is used.
Implementations
Sourceimpl CreateTableBranchRequest
impl CreateTableBranchRequest
pub fn new(name: String) -> CreateTableBranchRequest