Module create_table_request

Module create_table_request 

Structs

CreateTableRequest
CreateTableRequest : Request for creating a table, excluding the Arrow IPC stream. The table location and any credential vending behavior are determined by the implementation and returned in the response, rather than specified in this request.