Module create_table_version_entry

Module create_table_version_entry 

Structs

CreateTableVersionEntry
CreateTableVersionEntry : An entry for creating a new table version in a batch operation. This supports put_if_not_exists semantics, where the operation fails if the version already exists.