Structs
- Create
Table Version Request - CreateTableVersionRequest : Request to create a new table version entry. This supports
put_if_not_existssemantics, where the operation fails if the version already exists.
put_if_not_exists semantics, where the operation fails if the version already exists.