pub struct DeclareTableRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub location: Option<String>,
pub vend_credentials: Option<bool>,
pub properties: Option<HashMap<String, String>>,
}Expand description
DeclareTableRequest : Request for declaring a table.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
id: Option<Vec<String>>location: Option<String>Optional storage location for the table. If not provided, the namespace implementation should determine the table location.
vend_credentials: Option<bool>Whether to include vended credentials in the response storage_options. When true, the implementation should provide vended credentials for accessing storage. When not set, the implementation can decide whether to return vended credentials.
properties: Option<HashMap<String, String>>Business logic properties stored and managed by the namespace implementation outside Lance context, if supported by the implementation.
Implementations
Sourceimpl DeclareTableRequest
impl DeclareTableRequest
Sourcepub fn new() -> DeclareTableRequest
pub fn new() -> DeclareTableRequest
Request for declaring a table.