pub struct DescribeTableVersionResponse {
pub context: Option<HashMap<String, String>>,
pub version: Box<TableVersion>,
}Expand description
DescribeTableVersionResponse : Response containing the table version information
Fields
context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
version: Box<TableVersion>The table version information
Implementations
Sourceimpl DescribeTableVersionResponse
impl DescribeTableVersionResponse
Sourcepub fn new(version: TableVersion) -> DescribeTableVersionResponse
pub fn new(version: TableVersion) -> DescribeTableVersionResponse
Response containing the table version information