pub struct DropNamespaceResponse {
pub context: Option<HashMap<String, String>>,
pub properties: Option<HashMap<String, String>>,
pub transaction_id: Option<Vec<String>>,
}Fields
context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
properties: Option<HashMap<String, String>>If the implementation does not support namespace properties, it should return null for this field. Otherwise it should return the properties.
transaction_id: Option<Vec<String>>If present, indicating the operation is long running and should be tracked using DescribeTransaction
Implementations
Sourceimpl DropNamespaceResponse
impl DropNamespaceResponse
pub fn new() -> DropNamespaceResponse