pub struct GetTableStatsResponse {
pub context: Option<HashMap<String, String>>,
pub total_bytes: i64,
pub num_rows: i64,
pub num_indices: i64,
pub fragment_stats: Box<FragmentStats>,
}Fields
context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
total_bytes: i64The total number of bytes in the table
num_rows: i64The number of rows in the table
num_indices: i64The number of indices in the table
fragment_stats: Box<FragmentStats>Statistics on table fragments
Implementations
Sourceimpl GetTableStatsResponse
impl GetTableStatsResponse
pub fn new( total_bytes: i64, num_rows: i64, num_indices: i64, fragment_stats: FragmentStats, ) -> GetTableStatsResponse