pub struct InsertIntoTableRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub branch: Option<String>,
pub mode: Option<String>,
}Expand description
InsertIntoTableRequest : Request for inserting records into a table, excluding the Arrow IPC stream.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
id: Option<Vec<String>>branch: Option<String>Branch to target. When not specified, the main branch is used.
mode: Option<String>How the insert should behave. Case insensitive, supports both PascalCase and snake_case. Valid values are: - Append (default): insert data to the existing table - Overwrite: remove all data in the table and then insert data to it
Implementations
Sourceimpl InsertIntoTableRequest
impl InsertIntoTableRequest
Sourcepub fn new() -> InsertIntoTableRequest
pub fn new() -> InsertIntoTableRequest
Request for inserting records into a table, excluding the Arrow IPC stream.