pub struct ListTableBranchesRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub page_token: Option<String>,
pub limit: Option<i32>,
}Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>The table identifier
page_token: Option<String>An opaque token that allows pagination for list operations (e.g. ListNamespaces). For an initial request of a list operation, if the implementation cannot return all items in one response, or if there are more items than the page limit specified in the request, the implementation must return a page token in the response, indicating there are more results available. After the initial request, the value of the page token from each response must be used as the page token value for the next request. Caller must interpret either null, missing value or empty string value of the page token from the implementation’s response as the end of the listing results.
limit: Option<i32>An inclusive upper bound of the number of results that a caller will receive.
Implementations
Sourceimpl ListTableBranchesRequest
impl ListTableBranchesRequest
pub fn new() -> ListTableBranchesRequest