pub struct PartitionField {
pub field_id: String,
pub source_ids: Vec<i32>,
pub transform: Option<Box<PartitionTransform>>,
pub expression: Option<String>,
pub result_type: Box<JsonArrowDataType>,
}Expand description
PartitionField : Partition field definition
Fields
field_id: StringUnique identifier for this partition field (must not be renamed)
source_ids: Vec<i32>Field IDs of the source columns in the schema
transform: Option<Box<PartitionTransform>>Well-known partition transform. Exactly one of transform or expression must be specified.
expression: Option<String>DataFusion SQL expression using col0, col1, … as column references. Exactly one of transform or expression must be specified.
result_type: Box<JsonArrowDataType>The output type of the partition value (JsonArrowDataType format)
Implementations
Sourceimpl PartitionField
impl PartitionField
Sourcepub fn new(
field_id: String,
source_ids: Vec<i32>,
result_type: JsonArrowDataType,
) -> PartitionField
pub fn new( field_id: String, source_ids: Vec<i32>, result_type: JsonArrowDataType, ) -> PartitionField
Partition field definition