Module query_table_response

Module query_table_response 

Structs

QueryTableResponse
QueryTableResponse : Query results. The REST namespace does not transmit this object directly (see the QueryTable operation for how the Arrow IPC binary response maps to it). It is the standard data model for the LanceNamespace interfaces (e.g. Java, Python).