pub struct BatchCreateTableVersionsResponse {
pub transaction_id: Option<String>,
pub versions: Vec<TableVersion>,
}Expand description
BatchCreateTableVersionsResponse : Response for batch creating table versions. Contains the created versions for each table in the same order as the request.
Fields
transaction_id: Option<String>Optional transaction identifier
versions: Vec<TableVersion>List of created table versions in the same order as the request entries
Implementations
Sourceimpl BatchCreateTableVersionsResponse
impl BatchCreateTableVersionsResponse
Sourcepub fn new(versions: Vec<TableVersion>) -> BatchCreateTableVersionsResponse
pub fn new(versions: Vec<TableVersion>) -> BatchCreateTableVersionsResponse
Response for batch creating table versions. Contains the created versions for each table in the same order as the request.