pub struct BranchContents {
pub parent_branch: Option<String>,
pub parent_version: i64,
pub create_at: i64,
pub manifest_size: i64,
pub metadata: Option<HashMap<String, String>>,
}Fields
parent_branch: Option<String>Name of the branch this branch was created from. Absent when the branch was created from the main branch.
parent_version: i64Version of the parent (branch or main) this branch was created from
create_at: i64Unix timestamp (in seconds) when the branch was created
manifest_size: i64Size of the branch’s manifest file in bytes
metadata: Option<HashMap<String, String>>Key-value metadata associated with the branch
Implementations