CommitTableResult

Struct CommitTableResult 

pub struct CommitTableResult {
    pub declare_table: Option<Box<DeclareTableResponse>>,
    pub create_table_version: Option<Box<CreateTableVersionResponse>>,
    pub delete_table_versions: Option<Box<BatchDeleteTableVersionsResponse>>,
    pub deregister_table: Option<Box<DeregisterTableResponse>>,
}
CommitTableResult : Result of a single operation within a batch commit. Each result corresponds to one operation in the request, in the same order. Exactly one of the result fields will be set.

Fields

declare_table: Option<Box<DeclareTableResponse>>

Result of a DeclareTable operation

create_table_version: Option<Box<CreateTableVersionResponse>>

Result of a CreateTableVersion operation

delete_table_versions: Option<Box<BatchDeleteTableVersionsResponse>>

Result of a DeleteTableVersions operation

deregister_table: Option<Box<DeregisterTableResponse>>

Result of a DeregisterTable operation

Implementations

Source

impl CommitTableResult

pub fn new() -> CommitTableResult

Result of a single operation within a batch commit. Each result corresponds to one operation in the request, in the same order. Exactly one of the result fields will be set.