pub struct CreateTableVersionRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub version: i64,
pub manifest_path: String,
pub manifest_size: Option<i64>,
pub e_tag: Option<String>,
pub metadata: Option<HashMap<String, String>>,
pub naming_scheme: Option<String>,
}Expand description
CreateTableVersionRequest : Request to create a new table version entry. This supports put_if_not_exists semantics, where the operation fails if the version already exists.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>The table identifier
version: i64Version number to create
manifest_path: StringPath to the manifest file for this version
manifest_size: Option<i64>Size of the manifest file in bytes
e_tag: Option<String>Optional ETag for the manifest file
metadata: Option<HashMap<String, String>>Optional metadata for the version
naming_scheme: Option<String>The naming scheme used for manifest files in the _versions/ directory. Known values: - V1: _versions/{version}.manifest - Simple version-based naming - V2: _versions/{inverted_version}.manifest - Zero-padded, reversed version number (uses u64::MAX - version) for O(1) lookup of latest version on object stores V2 is preferred for new tables as it enables efficient latest-version discovery without needing to list all versions.
Implementations
Sourceimpl CreateTableVersionRequest
impl CreateTableVersionRequest
Sourcepub fn new(version: i64, manifest_path: String) -> CreateTableVersionRequest
pub fn new(version: i64, manifest_path: String) -> CreateTableVersionRequest
Request to create a new table version entry. This supports put_if_not_exists semantics, where the operation fails if the version already exists.