pub struct DeclareTableResponse {
pub transaction_id: Option<String>,
pub location: Option<String>,
pub storage_options: Option<HashMap<String, String>>,
pub properties: Option<HashMap<String, String>>,
pub managed_versioning: Option<bool>,
}Expand description
DeclareTableResponse : Response for declaring a table.
Fields
transaction_id: Option<String>Optional transaction identifier
location: Option<String>storage_options: Option<HashMap<String, String>>Configuration options to be used to access storage. The available options depend on the type of storage in use. These will be passed directly to Lance to initialize storage access.
properties: Option<HashMap<String, String>>If the implementation does not support table properties, it should return null for this field. Otherwise it should return the properties.
managed_versioning: Option<bool>When true, the caller should use namespace table version operations (CreateTableVersion, BatchCreateTableVersions, DescribeTableVersion, ListTableVersions, BatchDeleteTableVersions) to manage table versions instead of relying on Lance’s native version management.
Implementations
Sourceimpl DeclareTableResponse
impl DeclareTableResponse
Sourcepub fn new() -> DeclareTableResponse
pub fn new() -> DeclareTableResponse
Response for declaring a table.