pub struct DeleteFromTableRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub branch: Option<String>,
pub predicate: String,
}Expand description
DeleteFromTableRequest : Delete data from table based on a SQL predicate. Returns the number of rows that were deleted.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
id: Option<Vec<String>>The namespace identifier
branch: Option<String>Branch to target. When not specified, the main branch is used.
predicate: StringSQL predicate to filter rows for deletion. Field references must use Lance field path syntax: nested fields use dot-separated segments, literal dots require backtick-quoted segments, and backticks inside quoted segments are doubled.
Implementations
Sourceimpl DeleteFromTableRequest
impl DeleteFromTableRequest
Sourcepub fn new(predicate: String) -> DeleteFromTableRequest
pub fn new(predicate: String) -> DeleteFromTableRequest
Delete data from table based on a SQL predicate. Returns the number of rows that were deleted.