pub struct DescribeTableRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub version: Option<i64>,
pub tag: Option<String>,
pub branch: Option<String>,
pub with_table_uri: Option<bool>,
pub load_detailed_metadata: Option<bool>,
pub check_declared: Option<bool>,
pub vend_credentials: Option<bool>,
}Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context as key-value pairs. How to use the context is custom to the specific implementation. On a request, it carries caller-provided context to the implementation. On a response, it carries implementation-provided context back to the caller. REST NAMESPACE ONLY Context entries are mapped to and from HTTP headers using the header. prefix: - On a request, any entry whose key starts with header. is sent as an HTTP request header with the prefix stripped. For example, the entry {\"header.Authorization\": \"Bearer abc\"} is sent as the request header Authorization: Bearer abc. - On a response, every HTTP response header is returned as an entry whose key is the header name prefixed with header.. For example, the response header x-request-id: abc123 is returned as the entry {\"header.x-request-id\": \"abc123\"}.
id: Option<Vec<String>>version: Option<i64>Version of the table to describe. If not specified, server should resolve it to the latest version.
tag: Option<String>Tag name to describe the table at. If specified, the server should resolve the tag to a version number and describe that version. Cannot be used together with version or branch.
branch: Option<String>Branch to target. When not specified, the main branch is used.
with_table_uri: Option<bool>Whether to include the table URI in the response. Default is false.
load_detailed_metadata: Option<bool>Whether to load detailed metadata that requires opening the dataset. When true, the response must include all detailed metadata such as version, schema, and stats which require reading the dataset. When not set, the implementation can decide whether to return detailed metadata and which parts of detailed metadata to return.
check_declared: Option<bool>Whether to check if the table exists only as a namespace declaration without storage data. Default is false. When true, the response should populate is_only_declared. When false, the implementation should return null for is_only_declared unless another option such as load_detailed_metadata requires checking declared-only table state.
vend_credentials: Option<bool>Whether to include vended credentials in the response storage_options. When true, the implementation should provide vended credentials for accessing storage. When not set, the implementation can decide whether to return vended credentials.
Implementations
Sourceimpl DescribeTableRequest
impl DescribeTableRequest
pub fn new() -> DescribeTableRequest