pub async fn create_table_branch(
configuration: &Configuration,
id: &str,
create_table_branch_request: CreateTableBranchRequest,
delimiter: Option<&str>,
) -> Result<CreateTableBranchResponse, Error<CreateTableBranchError>>Expand description
Create a new branch for table id starting from a source ref (another branch and/or version), defaulting to the latest version of the main branch.