pub async fn declare_table(
configuration: &Configuration,
id: &str,
declare_table_request: DeclareTableRequest,
delimiter: Option<&str>,
) -> Result<DeclareTableResponse, Error<DeclareTableError>>Expand description
Declare a table with the given name without touching storage. This is a metadata-only operation that records the table existence and sets up aspects like access control. For DirectoryNamespace implementation, this creates a .lance-reserved file in the table directory to mark the table’s existence without creating actual Lance data files.