Structs
- Create
Table Version Entry - CreateTableVersionEntry : An entry for creating a new table version in a batch operation. This supports
put_if_not_existssemantics, where the operation fails if the version already exists.
put_if_not_exists semantics, where the operation fails if the version already exists.