pub struct RegisterTableRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub location: String,
pub mode: Option<String>,
pub properties: Option<HashMap<String, String>>,
}Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>location: Stringmode: Option<String>There are two modes when trying to register a table, to differentiate the behavior when a table of the same name already exists. Case insensitive, supports both PascalCase and snake_case. Valid values are: * Create (default): the operation fails with 409. * Overwrite: the existing table registration is replaced with the new registration.
properties: Option<HashMap<String, String>>Properties stored on the table, if supported by the implementation.
Implementations
Sourceimpl RegisterTableRequest
impl RegisterTableRequest
pub fn new(location: String) -> RegisterTableRequest