pub struct BatchCommitTablesRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub operations: Vec<CommitTableOperation>,
}Expand description
BatchCommitTablesRequest : Request to atomically commit a batch of table operations. This replaces BatchCreateTableVersionsRequest with a more general interface that supports mixed operations (DeclareTable, CreateTableVersion, DeleteTableVersions, DeregisterTable) within a single atomic transaction at the metadata layer. All operations are committed atomically: either all succeed or none are applied.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
operations: Vec<CommitTableOperation>List of operations to commit atomically. Supported operation types: DeclareTable, CreateTableVersion, DeleteTableVersions, DeregisterTable.
Implementations
Sourceimpl BatchCommitTablesRequest
impl BatchCommitTablesRequest
Sourcepub fn new(operations: Vec<CommitTableOperation>) -> BatchCommitTablesRequest
pub fn new(operations: Vec<CommitTableOperation>) -> BatchCommitTablesRequest
Request to atomically commit a batch of table operations. This replaces BatchCreateTableVersionsRequest with a more general interface that supports mixed operations (DeclareTable, CreateTableVersion, DeleteTableVersions, DeregisterTable) within a single atomic transaction at the metadata layer. All operations are committed atomically: either all succeed or none are applied.