pub struct BatchCreateTableVersionsRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub entries: Vec<CreateTableVersionEntry>,
}Expand description
BatchCreateTableVersionsRequest : Request to atomically create new version entries for multiple tables. The operation is atomic: all versions are created or none are.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
entries: Vec<CreateTableVersionEntry>List of table version entries to create atomically
Implementations
Sourceimpl BatchCreateTableVersionsRequest
impl BatchCreateTableVersionsRequest
Sourcepub fn new(
entries: Vec<CreateTableVersionEntry>,
) -> BatchCreateTableVersionsRequest
pub fn new( entries: Vec<CreateTableVersionEntry>, ) -> BatchCreateTableVersionsRequest
Request to atomically create new version entries for multiple tables. The operation is atomic: all versions are created or none are.