pub struct CreateTableIndexRequest {Show 16 fields
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub branch: Option<String>,
pub column: String,
pub index_type: String,
pub name: Option<String>,
pub distance_type: Option<String>,
pub with_position: Option<bool>,
pub base_tokenizer: Option<String>,
pub language: Option<String>,
pub max_token_length: Option<i32>,
pub lower_case: Option<bool>,
pub stem: Option<bool>,
pub remove_stop_words: Option<bool>,
pub ascii_folding: Option<bool>,
}Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>branch: Option<String>Branch to target. When not specified, the main branch is used.
column: StringLance field path to create the index on. Nested fields use dot-separated segments; use backtick-quoted segments for literal dots and double backticks inside quoted segments. Use canonical full paths for display and errors; leaf names alone only identify top-level fields; invalid or unresolved paths should return InvalidInput or TableColumnNotFound.
index_type: StringType of index to create (e.g., BTREE, BITMAP, LABEL_LIST, IVF_FLAT, IVF_PQ, IVF_HNSW_SQ, FTS)
name: Option<String>Optional name for the index. If not provided, a name will be auto-generated.
distance_type: Option<String>Distance metric type for vector indexes (e.g., l2, cosine, dot)
with_position: Option<bool>Optional FTS parameter for position tracking
base_tokenizer: Option<String>Optional FTS parameter for base tokenizer
language: Option<String>Optional FTS parameter for language
max_token_length: Option<i32>Optional FTS parameter for maximum token length
lower_case: Option<bool>Optional FTS parameter for lowercase conversion
stem: Option<bool>Optional FTS parameter for stemming
remove_stop_words: Option<bool>Optional FTS parameter for stop word removal
ascii_folding: Option<bool>Optional FTS parameter for ASCII folding
Implementations
Sourceimpl CreateTableIndexRequest
impl CreateTableIndexRequest
pub fn new(column: String, index_type: String) -> CreateTableIndexRequest